@@ -1,4 +1,5 @@
 import dataclasses
+import typing
 import torch
 import torchvision.datasets
 import irisml.core
@@ -22,6 +23,7 @@ class Task(irisml.core.TaskBase):
         train_dataset: torch.utils.data.Dataset = None
         val_dataset: torch.utils.data.Dataset = None
         num_classes: int = 0
+        class_names: typing.Optional[typing.List[str]] = dataclasses.field(default_factory=list)
 
     def execute(self, inputs):
         if not hasattr(torchvision.datasets, self.config.name):
@@ -31,8 +33,10 @@ class Task(irisml.core.TaskBase):
 
         train_dataset = dataset_class('.', train=True, download=True)
         val_dataset = dataset_class('.', train=False, download=True)
+        class_names = None
         if hasattr(train_dataset, 'classes'):
             num_classes = len(train_dataset.classes)
+            class_names = train_dataset.classes
         else:
             label_set = set()
             for i in range(len(train_dataset)):
@@ -40,4 +44,4 @@ class Task(irisml.core.TaskBase):
                 label_set.add(label)
             num_classes = len(label_set)
 
-        return self.Outputs(train_dataset=train_dataset, val_dataset=val_dataset, num_classes=num_classes)
+        return self.Outputs(train_dataset=train_dataset, val_dataset=val_dataset, num_classes=num_classes, class_names=class_names)
